==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/RadialLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredRadialSeriesDescriptionMetadata } from "./AnchoredRadialSeriesDescriptionMetadata";
import { RadialLineSeriesDescription } from "./RadialLineSeriesDescription";
/**
 * @hidden
 */
var RadialLineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(RadialLineSeriesDescriptionMetadata, _super);
    function RadialLineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RadialLineSeriesDescriptionMetadata.b = function (a) {
        if (RadialLineSeriesDescriptionMetadata.a == null) {
            RadialLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RadialLineSeriesDescriptionMetadata.c(RadialLineSeriesDescriptionMetadata.a);
        }
        if (a.j(RadialLineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(RadialLineSeriesDescriptionMetadata.a);
    };
    RadialLineSeriesDescriptionMetadata.c = function (a) {
        AnchoredRadialSeriesDescriptionMetadata.c(a);
        a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
        a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
    };
    RadialLineSeriesDescriptionMetadata.d = function (a) {
        RadialLineSeriesDescriptionMetadata.b(a);
        a.aa("RadialLineSeries", function () { return new RadialLineSeriesDescription(); });
        a.z("RadialLineSeries", RadialLineSeriesDescriptionMetadata.a);
    };
    RadialLineSeriesDescriptionMetadata.$t = markType(RadialLineSeriesDescriptionMetadata, 'RadialLineSeriesDescriptionMetadata');
    RadialLineSeriesDescriptionMetadata.a = null;
    return RadialLineSeriesDescriptionMetadata;
}(Base));
export { RadialLineSeriesDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/RadialLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredRadialSeriesDescriptionMetadata } from "./AnchoredRadialSeriesDescriptionMetadata";
import { RadialLineSeriesDescription } from "./RadialLineSeriesDescription";
/**
 * @hidden
 */
var RadialLineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(RadialLineSeriesDescriptionMetadata, _super);
    function RadialLineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RadialLineSeriesDescriptionMetadata.b = function (a) {
        if (RadialLineSeriesDescriptionMetadata.a == null) {
            RadialLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RadialLineSeriesDescriptionMetadata.c(RadialLineSeriesDescriptionMetadata.a);
        }
        if (a.k(RadialLineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(RadialLineSeriesDescriptionMetadata.a);
    };
    RadialLineSeriesDescriptionMetadata.c = function (a) {
        AnchoredRadialSeriesDescriptionMetadata.c(a);
        a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
        a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
    };
    RadialLineSeriesDescriptionMetadata.d = function (a) {
        RadialLineSeriesDescriptionMetadata.b(a);
        a.ac("RadialLineSeries", function () { return new RadialLineSeriesDescription(); });
        a.ab("RadialLineSeries", RadialLineSeriesDescriptionMetadata.a);
    };
    RadialLineSeriesDescriptionMetadata.$t = markType(RadialLineSeriesDescriptionMetadata, 'RadialLineSeriesDescriptionMetadata');
    RadialLineSeriesDescriptionMetadata.a = null;
    return RadialLineSeriesDescriptionMetadata;
}(Base));
export { RadialLineSeriesDescriptionMetadata };
